@@ -27,7 +27,7 @@
 class SdlPref
 {
   public:
-	[[nodiscard]] static std::shared_ptr<SdlPref>
+	static std::shared_ptr<SdlPref>
 	instance(const std::string& name = SdlPref::get_default_file(false));
 
 	[[nodiscard]] std::string get_pref_file(bool systemConfigOnly = false) const;
@@ -63,7 +63,7 @@ class SdlPref
 
 	[[nodiscard]] bool is_user_config_enabled() const;
 
-	[[nodiscard]] static std::string get_default_file(bool systemConfigOnly);
-	[[nodiscard]] static std::string item_to_str(WINPR_JSON* item,
-	                                             const std::string& fallback = "");
+	static std::string get_pref_dir(bool systemConfigOnly);
+	static std::string get_default_file(bool systemConfigOnly);
+	static std::string item_to_str(WINPR_JSON* item, const std::string& fallback = "");
 };
