@@ -186,6 +186,8 @@ static wStream* arm_build_http_request(rdpArm* arm, const char* method,
                                        size_t content_length)
 {
 	wStream* s = NULL;
+	HttpRequest* request = NULL;
+	const char* uri = NULL;
 
 	WINPR_ASSERT(arm);
 	WINPR_ASSERT(method);
@@ -194,18 +196,16 @@ static wStream* arm_build_http_request(rdpArm* arm, const char* method,
 	WINPR_ASSERT(arm->context);
 	WINPR_ASSERT(arm->context->rdp);
 
-	const char* uri = http_context_get_uri(arm->http);
-	HttpRequest* request = http_request_new();
+	uri = http_context_get_uri(arm->http);
+	request = http_request_new();
 
 	if (!request)
 		return NULL;
 
-	rdpSettings* settings = arm->context->settings;
-
 	if (!http_request_set_method(request, method) || !http_request_set_uri(request, uri))
 		goto out;
 
-	if (!freerdp_settings_get_string(settings, FreeRDP_GatewayHttpExtAuthBearer))
+	if (!freerdp_settings_get_string(arm->context->settings, FreeRDP_GatewayHttpExtAuthBearer))
 	{
 		char* token = NULL;
 
@@ -225,7 +225,8 @@ static wStream* arm_build_http_request(rdpArm* arm, const char* method,
 			goto out;
 		}
 
-		if (!freerdp_settings_set_string(settings, FreeRDP_GatewayHttpExtAuthBearer, token))
+		if (!freerdp_settings_set_string(arm->context->settings, FreeRDP_GatewayHttpExtAuthBearer,
+		                                 token))
 		{
 			free(token);
 			goto out;
@@ -235,7 +236,8 @@ static wStream* arm_build_http_request(rdpArm* arm, const char* method,
 
 	if (!http_request_set_auth_scheme(request, "Bearer") ||
 	    !http_request_set_auth_param(
-	        request, freerdp_settings_get_string(settings, FreeRDP_GatewayHttpExtAuthBearer)))
+	        request,
+	        freerdp_settings_get_string(arm->context->settings, FreeRDP_GatewayHttpExtAuthBearer)))
 		goto out;
 
 	if (!http_request_set_transfer_encoding(request, transferEncoding) ||
@@ -264,8 +266,6 @@ static BOOL arm_send_http_request(rdpArm* arm, rdpTls* tls, const char* method,
 		return FALSE;
 
 	const size_t sz = Stream_Length(s);
-	WLog_Print(arm->log, WLOG_TRACE, "header [%" PRIuz "]: %s", sz, Stream_Buffer(s));
-	WLog_Print(arm->log, WLOG_TRACE, "body   [%" PRIuz "]: %s", content_length, data);
 	status = freerdp_tls_write_all(tls, Stream_Buffer(s), sz);
 
 	Stream_Free(s, TRUE);
@@ -362,52 +362,51 @@ arm_create_cleanup:
  * @param cbInput size of pbInput
  * @return the corresponding WINPR_CIPHER_CTX if success, NULL otherwise
  */
-static WINPR_CIPHER_CTX* treatAuthBlob(wLog* log, const BYTE* pbInput, size_t cbInput,
-                                       size_t* pBlockSize)
+static WINPR_CIPHER_CTX* treatAuthBlob(wLog* log, const BYTE* pbInput, size_t cbInput)
 {
 	WINPR_CIPHER_CTX* ret = NULL;
 	char algoName[100] = { 0 };
 
-	WINPR_ASSERT(pBlockSize);
 	SSIZE_T algoSz = ConvertWCharNToUtf8((const WCHAR*)pbInput, cbInput / sizeof(WCHAR), algoName,
-	                                     sizeof(algoName) - 1);
+	                                     sizeof(algoName));
 	if (algoSz <= 0)
 	{
 		WLog_Print(log, WLOG_ERROR, "invalid algoName");
 		return NULL;
 	}
 
+	algoName[algoSz] = 0;
 	if (strcmp(algoName, "AES") != 0)
 	{
 		WLog_Print(log, WLOG_ERROR, "only AES is supported for now");
 		return NULL;
 	}
 
-	*pBlockSize = WINPR_AES_BLOCK_SIZE;
-	const size_t algoLen = WINPR_ASSERTING_INT_CAST(size_t, (algoSz + 1)) * sizeof(WCHAR);
-	if (cbInput < algoLen)
+	cbInput -= WINPR_ASSERTING_INT_CAST(size_t, (algoSz + 1)) * sizeof(WCHAR);
+
+	if (cbInput < 12)
 	{
 		WLog_Print(log, WLOG_ERROR, "invalid AuthBlob size");
 		return NULL;
 	}
 
-	cbInput -= algoLen;
-
 	/* BCRYPT_KEY_DATA_BLOB_HEADER */
 	wStream staticStream = { 0 };
-	wStream* s = Stream_StaticConstInit(&staticStream, &pbInput[algoLen], cbInput);
+	wStream* s = Stream_StaticConstInit(
+	    &staticStream, pbInput + WINPR_ASSERTING_INT_CAST(size_t, (algoSz + 1)) * sizeof(WCHAR),
+	    cbInput);
 
-	if (!Stream_CheckAndLogRequiredLengthWLog(log, s, 12))
-		return NULL;
+	UINT32 dwMagic = 0;
+	Stream_Read_UINT32(s, dwMagic);
 
-	const UINT32 dwMagic = Stream_Get_UINT32(s);
 	if (dwMagic != BCRYPT_KEY_DATA_BLOB_MAGIC)
 	{
 		WLog_Print(log, WLOG_ERROR, "unsupported authBlob type");
 		return NULL;
 	}
 
-	const UINT32 dwVersion = Stream_Get_UINT32(s);
+	UINT32 dwVersion = 0;
+	Stream_Read_UINT32(s, dwVersion);
 	if (dwVersion != BCRYPT_KEY_DATA_BLOB_VERSION1)
 	{
 		WLog_Print(log, WLOG_ERROR, "unsupported authBlob version %" PRIu32 ", expecting %d",
@@ -415,8 +414,11 @@ static WINPR_CIPHER_CTX* treatAuthBlob(wLog* log, const BYTE* pbInput, size_t cb
 		return NULL;
 	}
 
-	const UINT32 cbKeyData = Stream_Get_UINT32(s);
-	if (!Stream_CheckAndLogRequiredLengthWLog(log, s, cbKeyData))
+	UINT32 cbKeyData = 0;
+	Stream_Read_UINT32(s, cbKeyData);
+	cbInput -= 12;
+
+	if (cbKeyData > cbInput)
 	{
 		WLog_Print(log, WLOG_ERROR, "invalid authBlob size");
 		return NULL;
@@ -479,7 +481,7 @@ static BOOL arm_stringEncodeW(const BYTE* pin, size_t cbIn, BYTE** ppOut, size_t
 }
 
 static BOOL arm_encodeRedirectPasswd(wLog* log, rdpSettings* settings, const rdpCertificate* cert,
-                                     WINPR_CIPHER_CTX* cipher, size_t blockSize)
+                                     WINPR_CIPHER_CTX* cipher)
 {
 	BOOL ret = FALSE;
 	BYTE* output = NULL;
@@ -497,21 +499,13 @@ static BOOL arm_encodeRedirectPasswd(wLog* log, rdpSettings* settings, const rdp
 		return FALSE;
 	}
 
-	const size_t wpasswdBytes = (wpasswdLen + 1) * sizeof(WCHAR);
-	BYTE* encryptedPass = calloc(1, wpasswdBytes + blockSize); /* 16: block size of AES (padding) */
-
-	if (!encryptedPass)
-		goto out;
-
+	size_t wpasswdBytes = (wpasswdLen + 1) * sizeof(WCHAR);
+	BYTE* encryptedPass = calloc(1, wpasswdBytes + 16); /* 16: block size of AES (padding) */
 	size_t encryptedPassLen = 0;
-	if (!winpr_Cipher_Update(cipher, wpasswd, wpasswdBytes, encryptedPass, &encryptedPassLen))
-		goto out;
-
-	if (encryptedPassLen > wpasswdBytes)
-		goto out;
-
 	size_t finalLen = 0;
-	if (!winpr_Cipher_Final(cipher, &encryptedPass[encryptedPassLen], &finalLen))
+	if (!encryptedPass ||
+	    !winpr_Cipher_Update(cipher, wpasswd, wpasswdBytes, encryptedPass, &encryptedPassLen) ||
+	    !winpr_Cipher_Final(cipher, encryptedPass + encryptedPassLen, &finalLen))
 	{
 		WLog_Print(log, WLOG_ERROR, "error when ciphering password");
 		goto out;
@@ -520,6 +514,7 @@ static BOOL arm_encodeRedirectPasswd(wLog* log, rdpSettings* settings, const rdp
 
 	/* then encrypt(cipheredPass, publicKey(redirectedServerCert) */
 	size_t output_length = 0;
+
 	if (!freerdp_certificate_publickey_encrypt(cert, encryptedPass, encryptedPassLen, &output,
 	                                           &output_length))
 	{
@@ -631,12 +626,10 @@ static BOOL arm_pick_base64Utf16Field(wLog* log, const WINPR_JSON* json, const c
 static size_t arm_parse_ipvx_count(WINPR_JSON* ipvX)
 {
 	WINPR_ASSERT(ipvX);
-	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItemCaseSensitive(ipvX, "ipAddress");
+	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItem(ipvX, "ipAddress");
 	if (!ipAddress || !WINPR_JSON_IsArray(ipAddress))
 		return 0;
-
-	/* Each entry might contain a public and a private address */
-	return WINPR_JSON_GetArraySize(ipAddress) * 2;
+	return WINPR_JSON_GetArraySize(ipAddress);
 }
 
 static BOOL arm_parse_ipv6(rdpSettings* settings, WINPR_JSON* ipv6, size_t* pAddressIdx)
@@ -648,11 +641,10 @@ static BOOL arm_parse_ipv6(rdpSettings* settings, WINPR_JSON* ipv6, size_t* pAdd
 	if (!freerdp_settings_get_bool(settings, FreeRDP_IPv6Enabled))
 		return TRUE;
 
-	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItemCaseSensitive(ipv6, "ipAddress");
+	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItem(ipv6, "ipAddress");
 	if (!ipAddress || !WINPR_JSON_IsArray(ipAddress))
 		return TRUE;
 	const size_t naddresses = WINPR_JSON_GetArraySize(ipAddress);
-	const uint32_t count = freerdp_settings_get_uint32(settings, FreeRDP_TargetNetAddressCount);
 	for (size_t j = 0; j < naddresses; j++)
 	{
 		WINPR_JSON* adressN = WINPR_JSON_GetArrayItem(ipAddress, j);
@@ -662,13 +654,6 @@ static BOOL arm_parse_ipv6(rdpSettings* settings, WINPR_JSON* ipv6, size_t* pAdd
 		const char* addr = WINPR_JSON_GetStringValue(adressN);
 		if (utils_str_is_empty(addr))
 			continue;
-
-		if (*pAddressIdx >= count)
-		{
-			WLog_ERR(TAG, "Exceeded TargetNetAddresses, parsing failed");
-			return FALSE;
-		}
-
 		if (!freerdp_settings_set_pointer_array(settings, FreeRDP_TargetNetAddresses,
 		                                        (*pAddressIdx)++, addr))
 			return FALSE;
@@ -682,48 +667,35 @@ static BOOL arm_parse_ipv4(rdpSettings* settings, WINPR_JSON* ipv4, size_t* pAdd
 	WINPR_ASSERT(ipv4);
 	WINPR_ASSERT(pAddressIdx);
 
-	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItemCaseSensitive(ipv4, "ipAddress");
+	WINPR_JSON* ipAddress = WINPR_JSON_GetObjectItem(ipv4, "ipAddress");
 	if (!ipAddress || !WINPR_JSON_IsArray(ipAddress))
 		return TRUE;
 
 	const size_t naddresses = WINPR_JSON_GetArraySize(ipAddress);
-	const uint32_t count = freerdp_settings_get_uint32(settings, FreeRDP_TargetNetAddressCount);
 	for (size_t j = 0; j < naddresses; j++)
 	{
 		WINPR_JSON* adressN = WINPR_JSON_GetArrayItem(ipAddress, j);
 		if (!adressN)
 			continue;
 
-		WINPR_JSON* publicIpNode =
-		    WINPR_JSON_GetObjectItemCaseSensitive(adressN, "publicIpAddress");
+		WINPR_JSON* publicIpNode = WINPR_JSON_GetObjectItem(adressN, "publicIpAddress");
 		if (publicIpNode && WINPR_JSON_IsString(publicIpNode))
 		{
 			const char* publicIp = WINPR_JSON_GetStringValue(publicIpNode);
 			if (!utils_str_is_empty(publicIp))
 			{
-				if (*pAddressIdx >= count)
-				{
-					WLog_ERR(TAG, "Exceeded TargetNetAddresses, parsing failed");
-					return FALSE;
-				}
 				if (!freerdp_settings_set_pointer_array(settings, FreeRDP_TargetNetAddresses,
 				                                        (*pAddressIdx)++, publicIp))
 					return FALSE;
 			}
 		}
 
-		WINPR_JSON* privateIpNode =
-		    WINPR_JSON_GetObjectItemCaseSensitive(adressN, "privateIpAddress");
+		WINPR_JSON* privateIpNode = WINPR_JSON_GetObjectItem(adressN, "privateIpAddress");
 		if (privateIpNode && WINPR_JSON_IsString(privateIpNode))
 		{
 			const char* privateIp = WINPR_JSON_GetStringValue(privateIpNode);
 			if (!utils_str_is_empty(privateIp))
 			{
-				if (*pAddressIdx >= count)
-				{
-					WLog_ERR(TAG, "Exceeded TargetNetAddresses, parsing failed");
-					return FALSE;
-				}
 				if (!freerdp_settings_set_pointer_array(settings, FreeRDP_TargetNetAddresses,
 				                                        (*pAddressIdx)++, privateIp))
 					return FALSE;
@@ -750,7 +722,7 @@ static BOOL arm_treat_azureInstanceNetworkMetadata(wLog* log, const char* metada
 		return FALSE;
 	}
 
-	WINPR_JSON* iface = WINPR_JSON_GetObjectItemCaseSensitive(json, "interface");
+	WINPR_JSON* iface = WINPR_JSON_GetObjectItem(json, "interface");
 	if (!iface)
 	{
 		ret = TRUE;
@@ -778,11 +750,11 @@ static BOOL arm_treat_azureInstanceNetworkMetadata(wLog* log, const char* metada
 		if (!interN)
 			continue;
 
-		WINPR_JSON* ipv6 = WINPR_JSON_GetObjectItemCaseSensitive(interN, "ipv6");
+		WINPR_JSON* ipv6 = WINPR_JSON_GetObjectItem(interN, "ipv6");
 		if (ipv6)
 			count += arm_parse_ipvx_count(ipv6);
 
-		WINPR_JSON* ipv4 = WINPR_JSON_GetObjectItemCaseSensitive(interN, "ipv4");
+		WINPR_JSON* ipv4 = WINPR_JSON_GetObjectItem(interN, "ipv4");
 		if (ipv4)
 			count += arm_parse_ipvx_count(ipv4);
 	}
@@ -797,14 +769,14 @@ static BOOL arm_treat_azureInstanceNetworkMetadata(wLog* log, const char* metada
 		if (!interN)
 			continue;
 
-		WINPR_JSON* ipv6 = WINPR_JSON_GetObjectItemCaseSensitive(interN, "ipv6");
+		WINPR_JSON* ipv6 = WINPR_JSON_GetObjectItem(interN, "ipv6");
 		if (ipv6)
 		{
 			if (!arm_parse_ipv6(settings, ipv6, &addressIdx))
 				goto out;
 		}
 
-		WINPR_JSON* ipv4 = WINPR_JSON_GetObjectItemCaseSensitive(interN, "ipv4");
+		WINPR_JSON* ipv4 = WINPR_JSON_GetObjectItem(interN, "ipv4");
 		if (ipv4)
 		{
 			if (!arm_parse_ipv4(settings, ipv4, &addressIdx))
@@ -817,129 +789,86 @@ static BOOL arm_treat_azureInstanceNetworkMetadata(wLog* log, const char* metada
 	if (!freerdp_settings_set_uint32(settings, FreeRDP_TargetNetAddressCount, (UINT32)addressIdx))
 		goto out;
 
-	ret = addressIdx > 0;
+	ret = freerdp_settings_get_uint32(settings, FreeRDP_TargetNetAddressCount) > 0;
 
 out:
 	WINPR_JSON_Delete(json);
 	return ret;
 }
 
-static void zfree(char* str)
+static BOOL arm_fill_rdstls(rdpArm* arm, rdpSettings* settings, const WINPR_JSON* json)
 {
-	if (str)
-	{
-		char* cur = str;
-		while (*cur != '\0')
-			*cur++ = '\0';
-	}
-	free(str);
-}
-
-static BOOL arm_fill_rdstls(rdpArm* arm, rdpSettings* settings, const WINPR_JSON* json,
-                            const rdpCertificate* redirectedServerCert)
-{
-	WINPR_ASSERT(arm);
-	BOOL ret = FALSE;
+	BOOL ret = TRUE;
+	BYTE* cert = NULL;
 	BYTE* authBlob = NULL;
-	WCHAR* wGUID = NULL;
+	rdpCertificate* redirectedServerCert = NULL;
 
-	const char* redirUser = freerdp_settings_get_string(settings, FreeRDP_RedirectionUsername);
-	if (redirUser)
+	do
 	{
-		if (!freerdp_settings_set_string(settings, FreeRDP_Username, redirUser))
-			goto end;
-	}
+		/* redirectedAuthGuid */
+		WINPR_JSON* redirectedAuthGuidNode =
+		    WINPR_JSON_GetObjectItemCaseSensitive(json, "redirectedAuthGuid");
+		if (!redirectedAuthGuidNode || !WINPR_JSON_IsString(redirectedAuthGuidNode))
+			break;
 
-	/* Azure/Entra requires the domain field to be set to 'AzureAD' in most cases.
-	 * Some setups have been reported to require a different one, so only supply the suggested
-	 * default if there was no other domain provided.
-	 */
-	const char* redirDomain = freerdp_settings_get_string(settings, FreeRDP_Domain);
-	if (!redirDomain)
-	{
-		if (!freerdp_settings_set_string(settings, FreeRDP_Domain, "AzureAD"))
-			goto end;
-	}
+		const char* redirectedAuthGuid = WINPR_JSON_GetStringValue(redirectedAuthGuidNode);
+		if (!redirectedAuthGuid)
+			break;
 
-	const char* duser = freerdp_settings_get_string(settings, FreeRDP_Username);
-	const char* ddomain = freerdp_settings_get_string(settings, FreeRDP_Domain);
-	const char* dpwd = freerdp_settings_get_string(settings, FreeRDP_Password);
-	if (!duser || !dpwd)
-	{
-		WINPR_ASSERT(arm->context);
-		WINPR_ASSERT(arm->context->instance);
+		WCHAR wGUID[72] = {
+			0
+		}; /* A GUID string is between 32 and 68 characters as string, depending on representation.
+		      Add a few extra bytes for braces et al */
+		const SSIZE_T wGUID_len = ConvertUtf8ToWChar(redirectedAuthGuid, wGUID, ARRAYSIZE(wGUID));
+		if (wGUID_len < 0)
+		{
+			WLog_Print(arm->log, WLOG_ERROR, "unable to allocate space for redirectedAuthGuid");
+			ret = FALSE;
+			goto endOfFunction;
+		}
 
-		char* username = NULL;
-		char* password = NULL;
-		char* domain = NULL;
+		BOOL status = freerdp_settings_set_pointer_len(
+		    settings, FreeRDP_RedirectionGuid, wGUID,
+		    WINPR_ASSERTING_INT_CAST(size_t, (wGUID_len + 1)) * sizeof(WCHAR));
+		if (!status)
+		{
+			WLog_Print(arm->log, WLOG_ERROR, "unable to set RedirectionGuid");
+			ret = FALSE;
+			goto endOfFunction;
+		}
 
-		if (ddomain)
-			domain = _strdup(ddomain);
-		if (duser)
-			username = _strdup(duser);
+		/* redirectedServerCert */
+		size_t certLen = 0;
+		if (!arm_pick_base64Utf16Field(arm->log, json, "redirectedServerCert", &cert, &certLen))
+			break;
 
-		const BOOL rc =
-		    IFCALLRESULT(FALSE, arm->context->instance->AuthenticateEx, arm->context->instance,
-		                 &username, &password, &domain, AUTH_RDSTLS);
+		if (!rdp_redirection_read_target_cert(&redirectedServerCert, cert, certLen))
+			break;
 
-		const BOOL rc1 = freerdp_settings_set_string(settings, FreeRDP_Username, username);
-		const BOOL rc2 = freerdp_settings_set_string(settings, FreeRDP_Password, password);
-		const BOOL rc3 = freerdp_settings_set_string(settings, FreeRDP_Domain, domain);
-		zfree(username);
-		zfree(password);
-		zfree(domain);
-		if (!rc || !rc1 || !rc2 || !rc3)
-			goto end;
-	}
+		/* redirectedAuthBlob */
+		size_t authBlobLen = 0;
+		if (!arm_pick_base64Utf16Field(arm->log, json, "redirectedAuthBlob", &authBlob,
+		                               &authBlobLen))
+			break;
 
-	/* redirectedAuthGuid */
-	WINPR_JSON* redirectedAuthGuidNode =
-	    WINPR_JSON_GetObjectItemCaseSensitive(json, "redirectedAuthGuid");
-	if (!redirectedAuthGuidNode || !WINPR_JSON_IsString(redirectedAuthGuidNode))
-		goto end;
+		WINPR_CIPHER_CTX* cipher = treatAuthBlob(arm->log, authBlob, authBlobLen);
+		if (!cipher)
+			break;
 
-	const char* redirectedAuthGuid = WINPR_JSON_GetStringValue(redirectedAuthGuidNode);
-	if (!redirectedAuthGuid)
-		goto end;
+		const BOOL rerp =
+		    arm_encodeRedirectPasswd(arm->log, settings, redirectedServerCert, cipher);
+		winpr_Cipher_Free(cipher);
+		if (!rerp)
+			break;
 
-	size_t wGUID_len = 0;
-	wGUID = ConvertUtf8ToWCharAlloc(redirectedAuthGuid, &wGUID_len);
-	if (!wGUID || (wGUID_len == 0))
-	{
-		WLog_Print(arm->log, WLOG_ERROR, "unable to allocate space for redirectedAuthGuid");
-		goto end;
-	}
+		ret = TRUE;
+	} while (FALSE);
 
-	const BOOL status = freerdp_settings_set_pointer_len(settings, FreeRDP_RedirectionGuid, wGUID,
-	                                                     (wGUID_len + 1) * sizeof(WCHAR));
-
-	if (!status)
-	{
-		WLog_Print(arm->log, WLOG_ERROR, "unable to set RedirectionGuid");
-		goto end;
-	}
-
-	/* redirectedAuthBlob */
-	size_t authBlobLen = 0;
-	if (!arm_pick_base64Utf16Field(arm->log, json, "redirectedAuthBlob", &authBlob, &authBlobLen))
-		goto end;
-
-	size_t blockSize = 0;
-	WINPR_CIPHER_CTX* cipher = treatAuthBlob(arm->log, authBlob, authBlobLen, &blockSize);
-	if (!cipher)
-		goto end;
-
-	const BOOL rerp =
-	    arm_encodeRedirectPasswd(arm->log, settings, redirectedServerCert, cipher, blockSize);
-	winpr_Cipher_Free(cipher);
-	if (!rerp)
-		goto end;
-
-	ret = TRUE;
-
-end:
-	free(wGUID);
+	free(cert);
+	freerdp_certificate_free(redirectedServerCert);
 	free(authBlob);
+
+endOfFunction:
 	return ret;
 }
 
@@ -949,107 +878,61 @@ static BOOL arm_fill_gateway_parameters(rdpArm* arm, const char* message, size_t
 	WINPR_ASSERT(arm->context);
 	WINPR_ASSERT(message);
 
-	rdpCertificate* redirectedServerCert = NULL;
 	WINPR_JSON* json = WINPR_JSON_ParseWithLength(message, len);
 	BOOL status = FALSE;
 	if (!json)
-	{
-		WLog_Print(arm->log, WLOG_ERROR, "Response data is not valid JSON: %s",
-		           WINPR_JSON_GetErrorPtr());
 		return FALSE;
-	}
-
-	if (WLog_IsLevelActive(arm->log, WLOG_DEBUG))
-	{
-		char* str = WINPR_JSON_PrintUnformatted(json);
-		WLog_Print(arm->log, WLOG_DEBUG, "Got HTTP Response data: %s", str);
-		free(str);
-	}
 
 	rdpSettings* settings = arm->context->settings;
-	WINPR_JSON* gwurl = WINPR_JSON_GetObjectItemCaseSensitive(json, "gatewayLocationPreWebSocket");
-	if (!gwurl)
-		gwurl = WINPR_JSON_GetObjectItemCaseSensitive(json, "gatewayLocation");
+	WINPR_JSON* gwurl = WINPR_JSON_GetObjectItemCaseSensitive(json, "gatewayLocation");
 	const char* gwurlstr = WINPR_JSON_GetStringValue(gwurl);
 	if (gwurlstr != NULL)
 	{
 		WLog_Print(arm->log, WLOG_DEBUG, "extracted target url %s", gwurlstr);
 		if (!freerdp_settings_set_string(settings, FreeRDP_GatewayUrl, gwurlstr))
-			goto fail;
+			status = FALSE;
+		else
+			status = TRUE;
 	}
 
-	WINPR_JSON* serverNameNode =
-	    WINPR_JSON_GetObjectItemCaseSensitive(json, "redirectedServerName");
+	WINPR_JSON* serverNameNode = WINPR_JSON_GetObjectItem(json, "redirectedServerName");
 	if (serverNameNode)
 	{
 		const char* serverName = WINPR_JSON_GetStringValue(serverNameNode);
 		if (serverName)
-		{
-			if (!freerdp_settings_set_string(settings, FreeRDP_ServerHostname, serverName))
-				goto fail;
-		}
+			status = freerdp_settings_set_string(settings, FreeRDP_ServerHostname, serverName);
 	}
 
-	{
-		const char key[] = "redirectedUsername";
-		if (WINPR_JSON_HasObjectItem(json, key))
-		{
-			const char* userName = NULL;
-			WINPR_JSON* userNameNode = WINPR_JSON_GetObjectItemCaseSensitive(json, key);
-			if (userNameNode)
-				userName = WINPR_JSON_GetStringValue(userNameNode);
-			if (!freerdp_settings_set_string(settings, FreeRDP_RedirectionUsername, userName))
-				goto fail;
-		}
-	}
-
-	WINPR_JSON* azureMeta =
-	    WINPR_JSON_GetObjectItemCaseSensitive(json, "azureInstanceNetworkMetadata");
+	WINPR_JSON* azureMeta = WINPR_JSON_GetObjectItem(json, "azureInstanceNetworkMetadata");
 	if (azureMeta && WINPR_JSON_IsString(azureMeta))
 	{
 		if (!arm_treat_azureInstanceNetworkMetadata(arm->log, WINPR_JSON_GetStringValue(azureMeta),
 		                                            settings))
 		{
 			WLog_Print(arm->log, WLOG_ERROR, "error when treating azureInstanceNetworkMetadata");
-			goto fail;
 		}
 	}
 
-	/* redirectedServerCert */
-	size_t certLen = 0;
-	BYTE* cert = NULL;
-	if (arm_pick_base64Utf16Field(arm->log, json, "redirectedServerCert", &cert, &certLen))
+	if (freerdp_settings_get_string(settings, FreeRDP_Password))
 	{
-		const BOOL rc = rdp_redirection_read_target_cert(&redirectedServerCert, cert, certLen);
-		free(cert);
-		if (!rc)
-			goto fail;
-		else if (!rdp_set_target_certificate(settings, redirectedServerCert))
-			goto fail;
+		/* note: we retrieve some more fields for RDSTLS only if we have a password provided by the
+		 * user, otherwise these are useless: we will not be able to do RDSTLS
+		 */
+		status = arm_fill_rdstls(arm, settings, json);
 	}
 
-	if (freerdp_settings_get_bool(settings, FreeRDP_AadSecurity))
-		status = TRUE;
-	else
-		status = arm_fill_rdstls(arm, settings, json, redirectedServerCert);
-
-fail:
 	WINPR_JSON_Delete(json);
-	freerdp_certificate_free(redirectedServerCert);
 	return status;
 }
 
 static BOOL arm_handle_request_ok(rdpArm* arm, const HttpResponse* response)
 {
 	const size_t len = http_response_get_body_length(response);
-	const char* msg = http_response_get_body(response);
-	const size_t alen = strnlen(msg, len + 1);
-	if (alen > len)
-	{
-		WLog_Print(arm->log, WLOG_ERROR, "Got HTTP Response data with invalid termination");
+	const char* msg = (const char*)http_response_get_body(response);
+	if (strnlen(msg, len + 1) > len)
 		return FALSE;
-	}
 
+	WLog_Print(arm->log, WLOG_DEBUG, "Got HTTP Response data: %s", msg);
 	return arm_fill_gateway_parameters(arm, msg, len);
 }
 
@@ -1062,16 +945,10 @@ static BOOL arm_handle_bad_request(rdpArm* arm, const HttpResponse* response, BO
 
 	BOOL rc = FALSE;
 
-	http_response_log_error_status(WLog_Get(TAG), WLOG_ERROR, response);
-
 	const size_t len = http_response_get_body_length(response);
-	const char* msg = http_response_get_body(response);
-	if (msg && (strnlen(msg, len + 1) > len))
-	{
-		WLog_Print(arm->log, WLOG_ERROR, "Got HTTP Response data, but length is invalid");
-
+	const char* msg = (const char*)http_response_get_body(response);
+	if (strnlen(msg, len + 1) > len)
 		return FALSE;
-	}
 
 	WLog_Print(arm->log, WLOG_DEBUG, "Got HTTP Response data: %s", msg);
 
@@ -1079,35 +956,35 @@ static BOOL arm_handle_bad_request(rdpArm* arm, const HttpResponse* response, BO
 	if (json == NULL)
 	{
 		const char* error_ptr = WINPR_JSON_GetErrorPtr();
-		WLog_Print(arm->log, WLOG_ERROR, "WINPR_JSON_ParseWithLength: %s", error_ptr);
+		if (error_ptr != NULL)
+			WLog_Print(arm->log, WLOG_ERROR, "NullPoException: %s", error_ptr);
 
 		return FALSE;
 	}
+
+	WINPR_JSON* gateway_code_obj = WINPR_JSON_GetObjectItemCaseSensitive(json, "Code");
+	const char* gw_code_str = WINPR_JSON_GetStringValue(gateway_code_obj);
+	if (gw_code_str == NULL)
+	{
+		WLog_Print(arm->log, WLOG_ERROR, "Response has no \"Code\" property");
+		http_response_log_error_status(WLog_Get(TAG), WLOG_ERROR, response);
+		goto fail;
+	}
+
+	if (strcmp(gw_code_str, "E_PROXY_ORCHESTRATION_LB_SESSIONHOST_DEALLOCATED") == 0)
+	{
+		*retry = TRUE;
+		WINPR_JSON* message = WINPR_JSON_GetObjectItemCaseSensitive(json, "Message");
+		const char* msgstr = WINPR_JSON_GetStringValue(message);
+		if (!msgstr)
+			WLog_WARN(TAG, "Starting your VM. It may take up to 5 minutes");
+		else
+			WLog_WARN(TAG, "%s", msgstr);
+	}
 	else
 	{
-		WINPR_JSON* gateway_code_obj = WINPR_JSON_GetObjectItemCaseSensitive(json, "Code");
-		const char* gw_code_str = WINPR_JSON_GetStringValue(gateway_code_obj);
-		if (gw_code_str == NULL)
-		{
-			WLog_Print(arm->log, WLOG_ERROR, "Response has no \"Code\" property");
-			goto fail;
-		}
-
-		if (strcmp(gw_code_str, "E_PROXY_ORCHESTRATION_LB_SESSIONHOST_DEALLOCATED") == 0)
-		{
-			*retry = TRUE;
-			WINPR_JSON* message = WINPR_JSON_GetObjectItemCaseSensitive(json, "Message");
-			const char* msgstr = WINPR_JSON_GetStringValue(message);
-			if (!msgstr)
-				WLog_WARN(TAG, "Starting your VM. It may take up to 5 minutes");
-			else
-				WLog_WARN(TAG, "%s", msgstr);
-			freerdp_set_last_error_if_not(arm->context, FREERDP_ERROR_CONNECT_TARGET_BOOTING);
-		}
-		else
-		{
-			goto fail;
-		}
+		http_response_log_error_status(WLog_Get(TAG), WLOG_ERROR, response);
+		goto fail;
 	}
 
 	rc = TRUE;
@@ -1134,17 +1011,13 @@ static BOOL arm_handle_request(rdpArm* arm, BOOL* retry, DWORD timeout)
 	HttpResponse* response = NULL;
 	long StatusCode = 0;
 
-	const char* useragent =
-	    freerdp_settings_get_string(arm->context->settings, FreeRDP_GatewayHttpUserAgent);
-	const char* msuseragent =
-	    freerdp_settings_get_string(arm->context->settings, FreeRDP_GatewayHttpMsUserAgent);
-	if (!http_context_set_uri(arm->http, "/api/arm/v2/connections") ||
-	    !http_context_set_accept(arm->http, "*/*") ||
+	if (!http_context_set_uri(arm->http, "/api/arm/v2/connections/") ||
+	    !http_context_set_accept(arm->http, "application/json") ||
 	    !http_context_set_cache_control(arm->http, "no-cache") ||
 	    !http_context_set_pragma(arm->http, "no-cache") ||
 	    !http_context_set_connection(arm->http, "Keep-Alive") ||
-	    !http_context_set_user_agent(arm->http, useragent) ||
-	    !http_context_set_x_ms_user_agent(arm->http, msuseragent) ||
+	    !http_context_set_user_agent(arm->http, FREERDP_USER_AGENT) ||
+	    !http_context_set_x_ms_user_agent(arm->http, FREERDP_USER_AGENT) ||
 	    !http_context_set_host(arm->http, freerdp_settings_get_string(arm->context->settings,
 	                                                                  FreeRDP_GatewayHostname)))
 		goto arm_error;
