@@ -206,8 +206,7 @@ typedef enum
 {
 	acceptance,
 	user_rejection,
-	provider_rejection,
-	negotiate_ack
+	provider_rejection
 } p_cont_def_result_t;
 
 typedef enum
@@ -254,19 +253,14 @@ typedef struct
 	char* port_spec; /* port string spec; size_is(length) */
 } port_any_t;
 
-typedef enum
-{
-	REASON_NOT_SPECIFIED = 0,
-	TEMPORARY_CONGESTION = 1,
-	LOCAL_LIMIT_EXCEEDED = 2,
-	CALLED_PADDR_UNKNOWN = 3,
-	PROTOCOL_VERSION_NOT_SUPPORTED = 4,
-	DEFAULT_CONTEXT_NOT_SUPPORTED = 5,
-	USER_DATA_NOT_READABLE = 6,
-	NO_PSAP_AVAILABLE = 7,
-	authentication_type_not_recognized = 8,
-	invalid_checksum = 9
-} bind_rejection_t;
+#define REASON_NOT_SPECIFIED 0
+#define TEMPORARY_CONGESTION 1
+#define LOCAL_LIMIT_EXCEEDED 2
+#define CALLED_PADDR_UNKNOWN 3
+#define PROTOCOL_VERSION_NOT_SUPPORTED 4
+#define DEFAULT_CONTEXT_NOT_SUPPORTED 5
+#define USER_DATA_NOT_READABLE 6
+#define NO_PSAP_AVAILABLE 7
 
 typedef UINT16 rpcrt_reason_code_t;
 
@@ -783,7 +777,6 @@ FREERDP_LOCAL SSIZE_T rpc_channel_read(RpcChannel* channel, wStream* s, size_t l
 FREERDP_LOCAL void rpc_channel_free(RpcChannel* channel);
 
 WINPR_ATTR_MALLOC(rpc_channel_free, 1)
-WINPR_ATTR_NODISCARD
 FREERDP_LOCAL RpcOutChannel* rpc_out_channel_new(rdpRpc* rpc, const GUID* guid);
 FREERDP_LOCAL int rpc_out_channel_replacement_connect(RpcOutChannel* outChannel, uint32_t timeout);
 
@@ -801,7 +794,6 @@ FREERDP_LOCAL BOOL rpc_connect(rdpRpc* rpc, UINT32 timeout);
 FREERDP_LOCAL void rpc_free(rdpRpc* rpc);
 
 WINPR_ATTR_MALLOC(rpc_free, 1)
-WINPR_ATTR_NODISCARD
 FREERDP_LOCAL rdpRpc* rpc_new(rdpTransport* transport);
 
 #endif /* FREERDP_LIB_CORE_GATEWAY_RPC_H */
