@@ -59,7 +59,6 @@ static int fail_at_(const COMMAND_LINE_ARGUMENT_A* arg, int rc, const char* file
 	return rc;
 }
 
-WINPR_ATTR_NODISCARD
 static int command_line_compare(const void* pa, const void* pb)
 {
 	const COMMAND_LINE_ARGUMENT_A* a = pa;
@@ -75,7 +74,6 @@ static int command_line_compare(const void* pa, const void* pb)
 	return strcmp(a->Name, b->Name);
 }
 
-WINPR_ATTR_NODISCARD
 static int shadow_server_print_command_line_help(int argc, char** argv,
                                                  const COMMAND_LINE_ARGUMENT_A* largs)
 {
@@ -593,10 +591,9 @@ int shadow_server_parse_command_line(rdpShadowServer* server, int argc, char** a
 				const MONITOR_DEF* monitor = &monitors[index];
 				const INT64 width = monitor->right - monitor->left + 1;
 				const INT64 height = monitor->bottom - monitor->top + 1;
-				WLog_INFO(
-				    TAG, "      %s [%" PRIu32 "] %" PRId64 "x%" PRId64 "\t+%" PRId32 "+%" PRId32 "",
-				    (monitor->flags == 1) ? "*" : " ", index, width, height, monitor->left,
-				    monitor->top);
+				WLog_INFO(TAG, "      %s [%d] %" PRId64 "x%" PRId64 "\t+%" PRId32 "+%" PRId32 "",
+				          (monitor->flags == 1) ? "*" : " ", index, width, height, monitor->left,
+				          monitor->top);
 			}
 
 			status = COMMAND_LINE_STATUS_PRINT;
@@ -614,15 +611,13 @@ int shadow_server_parse_command_line(rdpShadowServer* server, int argc, char** a
 	return status;
 }
 
-WINPR_ATTR_NODISCARD
 static DWORD WINAPI shadow_server_thread(LPVOID arg)
 {
 	rdpShadowServer* server = (rdpShadowServer*)arg;
 	BOOL running = TRUE;
 	DWORD status = 0;
 	freerdp_listener* listener = server->listener;
-	if (shadow_subsystem_start(server->subsystem) < 0)
-		running = FALSE;
+	shadow_subsystem_start(server->subsystem);
 
 	while (running)
 	{
@@ -681,7 +676,6 @@ static DWORD WINAPI shadow_server_thread(LPVOID arg)
 	return 0;
 }
 
-WINPR_ATTR_NODISCARD
 static BOOL open_port(rdpShadowServer* server, char* address)
 {
 	BOOL status = 0;
@@ -840,7 +834,6 @@ int shadow_server_stop(rdpShadowServer* server)
 	return 0;
 }
 
-WINPR_ATTR_NODISCARD
 static int shadow_server_init_config_path(rdpShadowServer* server)
 {
 	if (!server->ConfigPath)
@@ -866,7 +859,6 @@ static int shadow_server_init_config_path(rdpShadowServer* server)
 	return 1;
 }
 
-WINPR_ATTR_NODISCARD
 static BOOL shadow_server_create_certificate(rdpShadowServer* server, const char* filepath)
 {
 	BOOL rc = FALSE;
@@ -904,8 +896,6 @@ out_fail:
 	makecert_context_free(makecert);
 	return rc;
 }
-
-WINPR_ATTR_NODISCARD
 static BOOL shadow_server_init_certificate(rdpShadowServer* server)
 {
 	char* filepath = NULL;
@@ -944,42 +934,35 @@ static BOOL shadow_server_init_certificate(rdpShadowServer* server)
 			goto out_fail;
 	}
 
+	rdpSettings* settings = server->settings;
+	WINPR_ASSERT(settings);
+
+	rdpPrivateKey* key = freerdp_key_new_from_file_enc(server->PrivateKeyFile, NULL);
+	if (!key)
+		goto out_fail;
+	if (!freerdp_settings_set_pointer_len(settings, FreeRDP_RdpServerRsaKey, key, 1))
+		goto out_fail;
+
+	rdpCertificate* cert = freerdp_certificate_new_from_file(server->CertificateFile);
+	if (!cert)
+		goto out_fail;
+
+	if (!freerdp_settings_set_pointer_len(settings, FreeRDP_RdpServerCertificate, cert, 1))
+		goto out_fail;
+
+	if (!freerdp_certificate_is_rdp_security_compatible(cert))
 	{
-		rdpSettings* settings = server->settings;
-		WINPR_ASSERT(settings);
-
-		{
-			rdpPrivateKey* key = freerdp_key_new_from_file_enc(server->PrivateKeyFile, NULL);
-			if (!key)
-				goto out_fail;
-			if (!freerdp_settings_set_pointer_len(settings, FreeRDP_RdpServerRsaKey, key, 1))
-				goto out_fail;
-		}
-		{
-			rdpCertificate* cert = freerdp_certificate_new_from_file(server->CertificateFile);
-			if (!cert)
-				goto out_fail;
-
-			if (!freerdp_settings_set_pointer_len(settings, FreeRDP_RdpServerCertificate, cert, 1))
-				goto out_fail;
-
-			if (!freerdp_certificate_is_rdp_security_compatible(cert))
-			{
-				if (!freerdp_settings_set_bool(settings, FreeRDP_UseRdpSecurityLayer, FALSE))
-					goto out_fail;
-				if (!freerdp_settings_set_bool(settings, FreeRDP_RdpSecurity, FALSE))
-					goto out_fail;
-			}
-		}
+		if (!freerdp_settings_set_bool(settings, FreeRDP_UseRdpSecurityLayer, FALSE))
+			goto out_fail;
+		if (!freerdp_settings_set_bool(settings, FreeRDP_RdpSecurity, FALSE))
+			goto out_fail;
 	}
-
 	ret = TRUE;
 out_fail:
 	free(filepath);
 	return ret;
 }
 
-WINPR_ATTR_NODISCARD
 static BOOL shadow_server_check_peer_restrictions(freerdp_listener* listener)
 {
 	WINPR_ASSERT(listener);
@@ -1003,10 +986,8 @@ static BOOL shadow_server_check_peer_restrictions(freerdp_listener* listener)
 int shadow_server_init(rdpShadowServer* server)
 {
 	int status = 0;
-	if (!winpr_InitializeSSL(WINPR_SSL_INIT_DEFAULT))
-		return -1;
-	if (!WTSRegisterWtsApiFunctionTable(FreeRDP_InitWtsApi()))
-		return -1;
+	winpr_InitializeSSL(WINPR_SSL_INIT_DEFAULT);
+	WTSRegisterWtsApiFunctionTable(FreeRDP_InitWtsApi());
 
 	if (!(server->clients = ArrayList_New(TRUE)))
 		goto fail;
